@@ -4,7 +4,7 @@ use String::Urandom;
 
 my $su = new String::Urandom;
 
-$su->str_length(255);
+$su->str_length('255');
 $su->str_chars('a b c 1 2 3');
 
 my $length = $su->str_length;
@@ -13,7 +13,7 @@ my $string = $su->rand_string;
 
 print <<RESULTS;
    Length: $length
-   Chars: @$chars
+   Chars:  @$chars
    Result: $string
 RESULTS
 
